@@ -9,7 +9,7 @@ use Class::MOP::Method::Accessor;
 use Carp         'confess';
 use Scalar::Util 'blessed', 'weaken';
 
-our $VERSION   = '0.81';
+our $VERSION   = '0.82';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -331,7 +331,7 @@ sub accessor_metaclass { 'Class::MOP::Method::Accessor' }
 sub process_accessors {
     Carp::cluck('The process_accessors method has been made private.'
         . " The public version is deprecated and will be removed in a future release.\n");
-    shift->_process_accessors;
+    shift->_process_accessors(@_);
 }
 
 sub _process_accessors {
